/*
 * Copyright 2023 Goodix.inc <xulinkun@goodix.com>
 *
 * SPDX-License-Identifier: LGPL-2.1-or-later
 */

#pragma once

#include <fwupdplugin.h>

#define FU_TYPE_GOODIXTP_FIRMWARE (fu_goodixtp_firmware_get_type())
G_DECLARE_DERIVABLE_TYPE(FuGoodixtpFirmware,
			 fu_goodixtp_firmware,
			 FU,
			 GOODIXTP_FIRMWARE,
			 FuFirmware)

struct _FuGoodixtpFirmwareClass {
	FuFirmwareClass parent_class;
};
